@@ -1,15 +1,15 @@
 /*!
 # fltk-webview
 
-This provides webview functionality for embedded fltk windows. This currently works on Windows and MacOS:
+This provides webview functionality for embedded fltk windows. This currently works on Windows:
 
 ## Usage
 
 ```rust,no_run
-use fltk::{prelude::*, *};
+use fltk::{app, enums::Event, prelude::*, window};
 
 fn main() {
-    let app = app::App::default();
+    let _app = app::App::default();
     let mut win = window::Window::default()
         .with_size(800, 600)
         .with_label("Webview");
@@ -18,17 +18,27 @@ fn main() {
         .center_of_parent();
     win.end();
     win.show();
-    
-    let mut wv = fltk_webview::Webview::from(false, &mut wv_win);
-    wv.navigate("http://google.com");
 
-    app.run().unwrap();
+    // close the app when the main window is closed
+    win.set_callback(|_| {
+        if app::event() == Event::Close {
+            std::process::exit(0);
+        }
+    });
+
+    let mut wv = fltk_webview::Webview::create(false, &mut wv_win);
+    wv.navigate("http://wikipedia.com");
+    
+    // the webview handles the main loop
+    wv.run();
 }
 ```
 */
 
 // Uses code from https://github.com/webview/webview_rust/blob/dev/src/webview.rs
 
+#![allow(unused_imports)]
+
 use webview_official_sys as wv;
 use fltk::{prelude::*, *};
 use std::{
@@ -38,6 +48,10 @@ use std::{
     sync::Arc,
 };
 
+#[cfg(target_os = "macos")]
+#[macro_use]
+extern crate objc;
+
 #[cfg(target_os = "linux")]
 use gdk_x11_sys as gdk;
 
@@ -79,7 +93,7 @@ impl Drop for Webview {
 
 impl Webview {
     /// Create a Webview from an embedded fltk window. Requires that the window is already shown
-    pub fn from(debug: bool, win: &mut window::Window) -> Webview {
+    pub fn create(debug: bool, win: &mut window::Window) -> Webview {
         assert!(win.shown());
         win.end();
         win.set_color(enums::Color::White);
@@ -94,9 +108,10 @@ impl Webview {
             }
             #[cfg(target_os = "macos")]
             {
+                let handle = win.raw_handle();
                 inner = wv::webview_create(
                     debug as i32,
-                    win.raw_handle() as *mut raw::c_void,
+                    handle as *mut raw::c_void,
                 );
             }
             #[cfg(target_os = "linux")]
@@ -203,4 +218,9 @@ impl Webview {
         let result = CString::safe_new(result);
         unsafe { wv::webview_return(*self.inner, seq.as_ptr(), status, result.as_ptr()) }
     }
+
+    /// Run the main loop of the webview
+    pub fn run(&self) {
+        unsafe { wv::webview_run(*self.inner) }
+    }
 }
